==> codingclash2020-0.0.5.tar.gz: codingclash2020-0.0.5/codingclash2020/game/constants.py <==
"""
Notes
Ranges are in euclidian distance
"""

# General constants
TIME_LIMIT = 0.1
DEFAULT_NUM_ROUNDS = 200

## Buildings

# HQ constants
HQ_HEALTH = 200
HQ_MAX_SPAWNS = 1
HQ_SENSE_RANGE = 36
HQ_SPAWN_RADIUS = 2
HQ_OIL_PRODUCTION = 8

# Refinery constants
REFINERY_HEALTH = 40
REFINERY_COST = 40
REFINERY_PRODUCTION = 2
REFINERY_SENSE_RANGE = 25

# Turrets constants
TURRET_HEALTH = 50
TURRET_COST = 15
TURRET_DAMAGE = 10
TURRET_ATTACK_COST = 3
TURRET_ATTACK_RANGE = 13
TURRET_SENSE_RANGE = 25
TURRET_AOE = 0

# Barracks constants
BARRACKS_HEALTH = 50
BARRACKS_COST = 25
BARRACKS_MAX_SPAWNS = 3
BARRACKS_SPAWN_RADIUS = 2
BARRACKS_SENSE_RANGE = 8

# Walls constants
WALL_HEALTH = 40
WALL_COST = 2

## Troops constants

# Builders constants
BUILDER_HEALTH = 75
BUILDER_COST = 10
BUILDER_SPAWN_RADIUS = 2
BUILDER_MAX_SPAWNS = 1
BUILDER_SPEED = 8
BUILDER_SENSE_RANGE = 20

# Tank constants
TANK_HEALTH = 75
TANK_COST = 10
TANK_DAMAGE = 30
TANK_ATTACK_COST = 5
TANK_ATTACK_RANGE = 2
TANK_SPEED = 2
TANK_SENSE_RANGE = 25
TANK_AOE = 0

# Gunner constants
GUNNER_HEALTH = 20
GUNNER_COST = 5
GUNNER_DAMAGE = 10
GUNNER_ATTACK_COST = 2
GUNNER_ATTACK_RANGE = 5
GUNNER_SPEED = 2
GUNNER_SENSE_RANGE = 36
GUNNER_AOE = 0

# Grenade launcher constants
GRENADER_HEALTH = 10
GRENADER_COST = 10
GRENADER_SPEED = 2
GRENADER_SENSE_RANGE = 25
# Stun grenade constants
GRENADER_STUN_TURNS = 2
GRENADER_STUN_COST = 10
GRENADER_STUN_AOE = 2
GRENADER_STUN_RANGE = 5
# Damage grenade constants
GRENADER_DAMAGE_COST = 6
GRENADER_DAMAGE_AOE = 2
GRENADER_DAMAGE_DAMAGE = 8
GRENADER_DAMAGE_RANGE = 5

# Blockchain constants
BLOCKCHAIN_BYTE_COUNT = 5
BLOCKCHAIN_MIN_NUM_SIZE = 0
BLOCKCHAIN_MAX_NUM_SIZE = 255

==> codingclash2020-1.1.1.tar.gz: codingclash2020-1.1.1/codingclash2020/game/constants.py <==
"""
Notes:
Ranges are in euclidian distance
"""

# General constants
TIME_LIMIT = 0.1
DEFAULT_NUM_ROUNDS = 200

## Buildings

# HQ constants
HQ_HEALTH = 200
HQ_MAX_SPAWNS = 1
HQ_SENSE_RANGE = 34
HQ_SPAWN_RADIUS = 2
HQ_OIL_PRODUCTION = 8

# Refinery constants
REFINERY_HEALTH = 40
REFINERY_COST = 50
REFINERY_PRODUCTION = 4
REFINERY_SENSE_RANGE = 25

# Turrets constants
TURRET_HEALTH = 50
TURRET_COST = 25
TURRET_DAMAGE = 15
TURRET_ATTACK_COST = 8
TURRET_ATTACK_RANGE = 20
TURRET_SENSE_RANGE = 25
TURRET_AOE = 0

# Barracks constants
BARRACKS_HEALTH = 50
BARRACKS_COST = 25
BARRACKS_MAX_SPAWNS = 3
BARRACKS_SPAWN_RADIUS = 2
BARRACKS_SENSE_RANGE = 17

# Walls constants
WALL_HEALTH = 40
WALL_COST = 5

## Troops constants

# Builders constants
BUILDER_HEALTH = 30
BUILDER_COST = 10
BUILDER_SPAWN_RADIUS = 2
BUILDER_MAX_SPAWNS = 1
BUILDER_SPEED = 2
BUILDER_SENSE_RANGE = 20

# Tank constants
TANK_HEALTH = 50
TANK_COST = 20
TANK_DAMAGE = 25
TANK_ATTACK_COST = 15
TANK_ATTACK_RANGE = 1
TANK_SPEED = 2
TANK_SENSE_RANGE = 25
TANK_AOE = 0

# Gunner constants
GUNNER_HEALTH = 20
GUNNER_COST = 8
GUNNER_DAMAGE = 15
GUNNER_ATTACK_COST = 4
GUNNER_ATTACK_RANGE = 13
GUNNER_SPEED = 2
GUNNER_SENSE_RANGE = 36
GUNNER_AOE = 0

# Grenade launcher constants
GRENADER_HEALTH = 10
GRENADER_COST = 15
GRENADER_SPEED = 2
GRENADER_SENSE_RANGE = 25
# Stun grenade constants
GRENADER_STUN_TURNS = 2
GRENADER_STUN_AROUND = 1
GRENADER_STUN_COST = 12
GRENADER_STUN_AOE = 2
GRENADER_STUN_RANGE = 5
# Damage grenade constants
GRENADER_DAMAGE_DAMAGE = 8
GRENADER_DAMAGE_AROUND = 4
GRENADER_DAMAGE_COST = 7
GRENADER_DAMAGE_AOE = 2
GRENADER_DAMAGE_RANGE = 5

# Blockchain constants
BLOCKCHAIN_BYTE_COUNT = 5
BLOCKCHAIN_MIN_NUM_SIZE = 0
BLOCKCHAIN_MAX_NUM_SIZE = 255
